@@ -160,7 +160,7 @@ def events(root_lexicon, text):
 def theme_by_name(name="default"):
     """Return a Theme from the default themes in the themes/ directory."""
     from .theme import Theme
-    return Theme.byname(name)
+    return Theme.by_name(name)
 
 
 def theme_from_file(filename):
