@@ -70,6 +70,7 @@ import collections
 import functools
 import os
 import re
+import reprlib
 
 from . import util
 from .lang.css import Css, Atrule, Rule, Value
@@ -124,6 +125,10 @@ class StyleSheet:
         self.filename = filename
         self._imported_filenames = []
 
+    def __repr__(self):
+        fnames = ', '.join(map(os.path.basename, self.filenames()))
+        return '<{} [{}]>'.format(self.__class__.__name__, fnames)
+
     @classmethod
     def load_from_data(cls, data):
         """Return a Css.root tree from data, handling the encoding."""
@@ -339,6 +344,9 @@ class Style:
     def __init__(self, rules):
         self.rules = rules
 
+    def __repr__(self):
+        return '<{} ({} rules)>'.format(self.__class__.__name__, len(self.rules))
+
     @style_query
     def select_element(self, element):
         """Select the rules that match with Element."""
@@ -379,6 +387,9 @@ class Atrules:
     def __init__(self, rules):
         self.rules = rules
 
+    def __repr__(self):
+        return '<{} ({} rules)>'.format(self.__class__.__name__, len(self.rules))
+
     @style_query
     def select(self, *keywords):
         for r in self.rules:
@@ -518,10 +529,7 @@ class AbstractElement:
 
     def match(self, prelude):
         """Match with a compound selector expression (``prelude`` part of Rule)."""
-        for selectors in prelude:
-            if not self.match_selectors(selectors):
-                return False
-        return True
+        return any(self.match_selectors(selectors) for selectors in prelude)
 
     def match_selectors(self, selectors):
         """Match with a list of selectors with operators in between."""
