@@ -60,8 +60,8 @@ ARG = ruleitem.VariableItem('arg')
 MATCH = ruleitem.VariableItem('match', (lambda m, n: m.group(m.lastindex + n)))
 """The regular expression match object.
 
-You can access a specific group using :obj:`MATCH(n)`; groups start with 1.
-Even :obj:`MATCH(n)[s]` is possible, which yields a slice of the matched text
+You can access a specific group using :obj:`MATCH[n]`; groups start with 1.
+Even :obj:`MATCH[n][s]` is possible, which yields a slice of the matched text
 in group ``n``.
 
 """
@@ -69,7 +69,7 @@ in group ``n``.
 TEXT = ruleitem.VariableItem('text')
 """The matched text.
 
-You can use :obj:`TEXT[n]` to get a slice of the matched text.
+You can use :obj:`TEXT[s]` to get a slice of the matched text.
 
 """
 
@@ -79,39 +79,36 @@ def call(predicate, *arguments):
 
 
 def select(index, *items):
-    """Yield the item pointed to by the index.
+    r"""Yield the item pointed to by the index.
 
     In most use cases the index will be the result of a predicate function,
     which returns an integer value (or True or False, which evaluate to 1 and 0,
     repectively).
 
-    The following example yields Keyword when the matched text could be found
-    in the keywords_list, and otherwise Name.Command::
+    The following example rule yield tokens for any word, giving it the Keyword
+    action when the matched text could be found in the keywords_list, and
+    otherwise Name.Command::
 
         keywords_list = ['def', 'class', 'for', 'if', 'else', 'return']
+
         def predicate(text):
             return text in keywords_list
-        select(call(predicate, TEXT), Name.Command, Keyword)
+
+        class MyLang(Language):
+            @lexicon
+            def root(cls):
+                yield r'\w+', select(call(predicate, TEXT), Name.Command, Keyword)
 
     If the selected item is a list or tuple, it is unrolled when injected
     into the rule.
 
+    (For this kind of membership testing, you could also use the
+    :func:`ifmember` helper function.)
+
     """
     return ruleitem.select(index, *items)
 
 
-def pattern(value):
-    """Yield the value (string or None), usable as regular expression.
-
-    If None, the whole rule is skipped. This rule item may only be used as
-    the first item in a rule, and of course, it may not depend on the TEXT
-    or MATCH variables, but it may depend on the ARG variable (which enables
-    you to create patterns that depend on the lexicon argument).
-
-    """
-    return ruleitem.pattern(value)
-
-
 def target(value, *lexicons):
     """Yield either an integer target value, or a (possibly derived) Lexicon.
 
@@ -161,7 +158,7 @@ def ifeq(a, b, result, else_result=()):
     second subgroup in the match object::
 
         yield r'([^\W\d]\w*)\s*([\(\]])', \
-            ifeq(MATCH(2), '(',
+            ifeq(MATCH[2], '(',
                  (bygroup(Name.Function, Delimiter), cls.func_call),
                  (bygroup(Name.Variable, Delimiter), cls.subscript))
 
@@ -186,6 +183,9 @@ def ifmember(item, sequence, result, else_result=()):
     ``\begin``, but checks membership in a list without the backslash
     prepended.
 
+    Membership testing is optimized for speed by turning the sequence into a
+    frozen set.
+
     """
     return select(call(operator.contains, frozenset(sequence), item),
         else_result, result)
@@ -203,10 +203,10 @@ def ifgroup(n, result, else_result=()):
 
     Shortcut for::
 
-        select(call(operator.ne, MATCH(n), None), else_result, result)
+        select(call(operator.ne, MATCH[n], None), else_result, result)
 
     """
-    return select(call(operator.ne, MATCH(n), None), else_result, result)
+    return select(call(operator.ne, MATCH[n], None), else_result, result)
 
 
 def gselect(*results, default=()):
@@ -334,6 +334,13 @@ def words(words, prefix="", suffix=""):
     expression. Using the word boundary character ``\b`` as suffix is
     recommended to be sure the match ends at a word end.
 
+    Here is an example::
+
+        >>> from parce.rule import words
+        >>> CONSTANTS = ('true', 'false', 'null')
+        >>> words(CONSTANTS, r'\b', r'\b')
+        '\\b(?:null|(?:fals|tru)e)\\b'
+
     """
     expr = regex.words2regexp(words)
     if prefix or suffix:
@@ -341,13 +348,19 @@ def words(words, prefix="", suffix=""):
     return expr
 
 
-def char(chars, positive=True):
+def chars(chars, positive=True):
     """Return a regular expression pattern matching one of the characters in
-    the specified string.
+    the specified string or iterable.
 
     If `positive` is False, the set of characters is complemented, i.e. the
     pattern matches any single character that is not in the specified string.
 
+    An example::
+
+        >>> from parce.rule import chars
+        >>> chars('zbdkeghjlmfnotpqaruscvx')
+        '[a-hj-vxz]'
+
     """
     negate = "" if positive else "^"
     return '[{}{}]'.format(negate, regex.make_charclass(chars))
@@ -356,17 +369,29 @@ def char(chars, positive=True):
 ### Dynamic patterns (depending on ARG)
 
 
+def pattern(value):
+    """Yield the value (string or None), usable as regular expression.
+
+    If None, the whole rule is skipped. This rule item may only be used as
+    the first item in a rule, and of course, it may not depend on the TEXT
+    or MATCH variables, but it may depend on the ARG variable (which enables
+    you to create patterns that depend on the lexicon argument).
+
+    """
+    return ruleitem.pattern(value)
+
+
 def arg(escape=True, prefix="", suffix="", default=None):
     r"""Create a pattern that contains the argument the current Lexicon was
     called with.
 
-    If there is no argument in the current lexicon, this
-    :class:`~parce.ruleitem.pattern` yields the default value, which is by
-    default None, resulting in the rule being skipped.
+    If there is no argument in the current lexicon, or the argument is not a
+    string, this :class:`~parce.ruleitem.pattern` yields the ``default`` value
+    (by default None, resulting in the rule being skipped).
 
-    When there is an argument, it is escaped using :func:`re.escape` (when
-    ``escape`` was set to True), and if given, ``prefix`` is prepended and
-    ``suffix`` is appended. When the default value is used, ``prefix`` and
+    When there is a string argument, it is escaped using :func:`re.escape`
+    (when ``escape`` was set to True), and if given, ``prefix`` is prepended
+    and ``suffix`` is appended. When the default value is used, ``prefix`` and
     ``suffix`` are not used.
 
     """
