@@ -51,7 +51,7 @@ In the ``themes/`` directory are bundled CSS themes that can be used.
 Instantiate a bundled theme with::
 
     >>> from parce.theme import Theme
-    >>> th = Theme.byname("default")
+    >>> th = Theme.by_name("default")
 
 To use a custom CSS theme file, load it using::
 
@@ -89,6 +89,7 @@ base action types.
 import collections
 import itertools
 import functools
+import os
 
 from . import css
 from . import themes
@@ -121,8 +122,12 @@ class Theme(AbstractTheme):
         self._css_text = stylesheet
         self.TextFormat = TextFormat
 
+    def __repr__(self):
+        fnames = ', '.join(map(os.path.basename, self.filenames()))
+        return '<{} [{}]>'.format(self.__class__.__name__, fnames)
+
     @classmethod
-    def byname(cls, name="default"):
+    def by_name(cls, name="default"):
         """Create Theme by name.
 
         The name is a CSS file in the themes/ directory, without the ".css"
@@ -169,9 +174,10 @@ class Theme(AbstractTheme):
         ``"current-line"``
             The TextFormat for the current line. If you use it, set only the
             *background* color in your theme file.
+        ``"leading-whitespace"``
+            The TextFormat to highlight leading whitespace, if desired.
         ``"trailing-whitespace"``
-            The TextFormat (use only the *background*) to highlight trailing
-            whitespace, if desired.
+            The TextFormat to highlight trailing whitespace, if desired.
         ``"eol-marker"``
             The *color* to draw a "end-of-line" marker with, if desired
 
